# Generated by Django 3.0.6 on 2020-05-27 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='About',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('whatweare', models.TextField(max_length=102400)),
                ('whatwedo', models.TextField(max_length=102400)),
                ('whoweare', models.TextField(max_length=102400)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('last_updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name': 'About',
                'verbose_name_plural': 'About',
                'db_table': 'about',
            },
        ),
    ]



from django.utils.html import format_html
from django.contrib import admin
from django.contrib.admin.widgets import AdminFileWidget
from django.db import models
from .models import About

class AboutAdmin(admin.ModelAdmin):

    search_fields = ['whatweare', 'whatwedo', 'whoweare']

    list_display = [ 'id', 'date_created', 'last_updated',
    'preview_whatweare', 'preview_whatwedo', 'preview_whoweare' ]

    fieldsets = [
        (None, {
            'fields': ['whatweare', 'whatwedo', 'whoweare'],
        }),
    ]

    def preview_whatweare(self, obj):
        return format_html(obj.whatweare)
    preview_whatweare.admin_order_field = 'whatweare'
    preview_whatweare.short_description = 'what we are'

    def preview_whatwedo(self, obj):
        return format_html(obj.whatwedo)
    preview_whatwedo.admin_order_field = 'whatwedo'
    preview_whatwedo.short_description = 'what we do'

    def preview_whoweare(self, obj):
        return format_html(obj.whoweare)
    preview_whoweare.admin_order_field = 'whoweare'
    preview_whoweare.short_description = 'who we are'

    readonly_fields = ['preview_whatweare', 'preview_whatwedo', 'preview_whoweare']

admin.site.register(About, AboutAdmin)



from django.shortcuts import render
from django.http import HttpResponse
from .models import About

def index(request):
    about_us_list = About.objects.all()
    context = {
        'about_us': about_us_list[0] if len(about_us_list) > 0 else []
    }

    return render(request, 'about/index.html', context=context)



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

__version__ = '0.0.1'

setup(
    name='ahlev_django_about',
    version=__version__,
    description='description',
    long_description='long description',
    long_description_content_type='text/x-rst',
    author='ahlev',
    author_email='ohahlev@gmail.com',
    include_package_data=True,
    url='https://github.com/ohahlev/ahlev_django_about',
    packages=find_packages(),
    install_requires=[
        'django-tinymce'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    zip_safe=False,
)

# Usage of setup.py:
# $> python setup.py register             # registering package on PYPI
# $> python setup.py build sdist upload   # build, make source dist and upload to PYPI



from django.db import models

class About(models.Model):
    whatweare = models.TextField(max_length=102400, blank=False, verbose_name='what we are')
    whatwedo = models.TextField(max_length=102400, blank=False, verbose_name='what we do')
    whoweare = models.TextField(max_length=102400, blank=False, verbose_name='whow we are')

    date_created = models.DateTimeField(auto_now_add=True)
    last_updated = models.DateTimeField(auto_now=True)

    class Meta:
        verbose_name = 'About'
        verbose_name_plural = 'About'
        db_table = 'about'

    def __str__(self):
        return "{}".format(self.id)
